==> ZenTaoPMS.max2.0.rc1.php7.2.zip: zentaopms/module/auditplan/lang/en.php <==
<?php
$lang->auditplan->create        = 'Create Plan';
$lang->auditplan->edit          = 'Edit Plan';
$lang->auditplan->browse        = 'Browse Plan';

$lang->auditplan->browseAction = 'Auditplan List';
$lang->auditplan->editAction   = 'Edit Auditplan';

$lang->auditplan->id            = 'ID';
$lang->auditplan->item          = 'Item';
$lang->auditplan->name          = 'Name';
$lang->auditplan->day           = 'Day';
$lang->auditplan->week          = 'Week';
$lang->auditplan->month         = 'Month';
$lang->auditplan->date          = 'Date';
$lang->auditplan->cycle         = 'Cycle';
$lang->auditplan->interval      = 'Interval';
$lang->auditplan->deadline      = 'Deadline';
$lang->auditplan->comment       = 'Comment';
$lang->auditplan->content       = 'Content';
$lang->auditplan->check         = 'Check';
$lang->auditplan->batchCheck    = 'Batch Check';
$lang->auditplan->checkedBy     = 'Checked By';
$lang->auditplan->result        = 'Results';
$lang->auditplan->noData        = 'No Data';
$lang->auditplan->noCheckList   = 'There is no corresponding checklist, please go to the system module to create.';
$lang->auditplan->common        = 'Audit Plan';
$lang->auditplan->saveDraft     = 'Save Draft';
$lang->auditplan->batchCreate   = 'Batch Create';
$lang->auditplan->nc            = 'Non-conformities';
$lang->auditplan->process       = 'Process';
$lang->auditplan->processType   = 'Process Type';
$lang->auditplan->objectType    = 'Object Type';
$lang->auditplan->objectID      = 'Object ID';
$lang->auditplan->activity      = 'Activity';
$lang->auditplan->zoutput       = 'Output';
$lang->auditplan->status        = 'Status';
$lang->auditplan->severity      = 'Serverity';
$lang->auditplan->createdBy     = 'Created By';
$lang->auditplan->createdDate   = 'Created Date';
$lang->auditplan->createNc      = 'Create Nc';
$lang->auditplan->desc          = 'Description';
$lang->auditplan->assignedTo    = 'Assigned To';
$lang->auditplan->checkDate     = 'Check Date';
$lang->auditplan->realCheckDate = 'Real Check Date';

$lang->auditplan->commentEmpty  = 'When the result is no, the comment can not be empty.';
$lang->auditplan->confirmDelete = 'Do you want to delete this auditplan?';

$lang->auditplan->statusList = array();
$lang->auditplan->statusList['all']      = 'All';
$lang->auditplan->statusList['wait']     = 'Wait';
$lang->auditplan->statusList['checked']  = 'Checked';
$lang->auditplan->statusList['checking'] = 'Checking';
$lang->auditplan->statusList['assignTo'] = 'AssignedToMe';
$lang->auditplan->statusList['delay']    = 'Delayed';
$lang->auditplan->statusList['today']    = 'Today';

$lang->auditplan->moreStatusList = array();
$lang->auditplan->moreStatusList['yesterday'] = 'Yesterday';
$lang->auditplan->moreStatusList['lastMonth'] = 'Last Month';
$lang->auditplan->moreStatusList['month']     = 'This Month';
$lang->auditplan->moreStatusList['nextMonth'] = 'Next Month';

$lang->auditplan->resultList = array();
$lang->auditplan->resultList['pass']    = 'Pass';
$lang->auditplan->resultList['fail']    = 'Fail';
$lang->auditplan->resultList['useless'] = 'Not Applicable';

==> ZenTaoPMS.max2.2.php7.2_7.4.zip: zentaopms/module/auditplan/lang/en.php <==
<?php
$lang->auditplan->create        = 'Create Plan';
$lang->auditplan->edit          = 'Edit Plan';
$lang->auditplan->browse        = 'Browse Plan';

$lang->auditplan->browseAction = 'Auditplan List';
$lang->auditplan->editAction   = 'Edit Auditplan';

$lang->auditplan->id            = 'ID';
$lang->auditplan->item          = 'Item';
$lang->auditplan->name          = 'Name';
$lang->auditplan->day           = 'Day';
$lang->auditplan->week          = 'Week';
$lang->auditplan->month         = 'Month';
$lang->auditplan->date          = 'Date';
$lang->auditplan->cycle         = 'Cycle';
$lang->auditplan->interval      = 'Interval';
$lang->auditplan->deadline      = 'Deadline';
$lang->auditplan->comment       = 'Comment';
$lang->auditplan->content       = 'Content';
$lang->auditplan->check         = 'Check';
$lang->auditplan->batchCheck    = 'Batch Check';
$lang->auditplan->checkedBy     = 'Checked By';
$lang->auditplan->result        = 'Results';
$lang->auditplan->noData        = 'No Data';
$lang->auditplan->noCheckList   = 'There is no corresponding checklist, please go to the background module to create.';
$lang->auditplan->common        = 'Audit Plan';
$lang->auditplan->saveDraft     = 'Save Draft';
$lang->auditplan->batchCreate   = 'Batch Create';
$lang->auditplan->nc            = 'Non-conformities';
$lang->auditplan->process       = 'Process';
$lang->auditplan->processType   = 'Process Type';
$lang->auditplan->objectType    = 'Object Type';
$lang->auditplan->objectID      = 'Object ID';
$lang->auditplan->activity      = 'Activity';
$lang->auditplan->zoutput       = 'Output';
$lang->auditplan->status        = 'Status';
$lang->auditplan->severity      = 'Serverity';
$lang->auditplan->createdBy     = 'Created By';
$lang->auditplan->createdDate   = 'Created Date';
$lang->auditplan->createNc      = 'Create Nc';
$lang->auditplan->desc          = 'Description';
$lang->auditplan->assignedTo    = 'Assigned To';
$lang->auditplan->checkDate     = 'Check Date';
$lang->auditplan->realCheckDate = 'Real Check Date';

$lang->auditplan->commentEmpty  = 'When the result is no, the comment can not be empty.';
$lang->auditplan->confirmDelete = 'Do you want to delete this auditplan?';

$lang->auditplan->statusList = array();
$lang->auditplan->statusList['all']      = 'All';
$lang->auditplan->statusList['wait']     = 'Wait';
$lang->auditplan->statusList['checked']  = 'Checked';
$lang->auditplan->statusList['checking'] = 'Checking';
$lang->auditplan->statusList['assignTo'] = 'AssignedToMe';
$lang->auditplan->statusList['delay']    = 'Delayed';
$lang->auditplan->statusList['today']    = 'Today';

$lang->auditplan->moreStatusList = array();
$lang->auditplan->moreStatusList['yesterday'] = 'Yesterday';
$lang->auditplan->moreStatusList['lastMonth'] = 'Last Month';
$lang->auditplan->moreStatusList['month']     = 'This Month';
$lang->auditplan->moreStatusList['nextMonth'] = 'Next Month';

$lang->auditplan->resultList = array();
$lang->auditplan->resultList['pass']    = 'Pass';
$lang->auditplan->resultList['fail']    = 'Fail';
$lang->auditplan->resultList['useless'] = 'Not Applicable';
